@@ -1,5 +1,3 @@
-( cd opt/kde/share/doc/HTML/en/kdebase-apidocs ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kdebase-apidocs ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kdeprint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kdeprint ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kdebugdialog ; rm -rf common )
@@ -102,6 +100,8 @@
 ( cd opt/kde/share/doc/HTML/en/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/colors ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/performance ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/performance ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/kcmnotify ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/netpref ; rm -rf common )
@@ -172,6 +172,8 @@
 ( cd opt/kde/share/doc/HTML/en/kdm ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kdesu ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kompmgr ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kompmgr ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/ksysguard ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/ksysguard ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kioslave ; rm -rf common )
@@ -188,6 +190,10 @@
 ( cd opt/kde/lib ; ln -sf libkateinterfaces.so.0.0.0 libkateinterfaces.so.0 )
 ( cd opt/kde/lib ; rm -rf libkateinterfaces.so )
 ( cd opt/kde/lib ; ln -sf libkateinterfaces.so.0.0.0 libkateinterfaces.so )
+( cd opt/kde/lib ; rm -rf libkhotkeys_shared.so.1 )
+( cd opt/kde/lib ; ln -sf libkhotkeys_shared.so.1.0.0 libkhotkeys_shared.so.1 )
+( cd opt/kde/lib ; rm -rf libkhotkeys_shared.so )
+( cd opt/kde/lib ; ln -sf libkhotkeys_shared.so.1.0.0 libkhotkeys_shared.so )
 ( cd opt/kde/lib ; rm -rf libksplashthemes.so.0 )
 ( cd opt/kde/lib ; ln -sf libksplashthemes.so.0.0.0 libksplashthemes.so.0 )
 ( cd opt/kde/lib ; rm -rf libksplashthemes.so )
@@ -220,5 +226,9 @@
 ( cd opt/kde/lib ; ln -sf libkasbar.so.1.0.0 libkasbar.so.1 )
 ( cd opt/kde/lib ; rm -rf libkasbar.so )
 ( cd opt/kde/lib ; ln -sf libkasbar.so.1.0.0 libkasbar.so )
+( cd opt/kde/lib ; rm -rf libkfontinst.so.0 )
+( cd opt/kde/lib ; ln -sf libkfontinst.so.0.0.0 libkfontinst.so.0 )
+( cd opt/kde/lib ; rm -rf libkfontinst.so )
+( cd opt/kde/lib ; ln -sf libkfontinst.so.0.0.0 libkfontinst.so )
 ( cd opt/kde/bin ; rm -rf kinfocenter )
 ( cd opt/kde/bin ; ln -sf kcontrol kinfocenter )
